summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h b/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
index 1767922c..22c58732 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdidockcontainer.h
@@ -40,10 +40,10 @@ class KMDI_EXPORT KMdiDockContainer: public TQWidget, public KDockContainer
TQ_OBJECT
public:
- KMdiDockContainer( TQWidget *tqparent, TQWidget *win, int position, int flags );
+ KMdiDockContainer( TQWidget *parent, TQWidget *win, int position, int flags );
virtual ~KMdiDockContainer();
/** Get the KDockWidget that is our tqparent */
KDockWidget *parentDockWidget();
/**
@@ -91,18 +91,18 @@ public:
/**
* Save the config using a KConfig object
*
* The combination of the group_or_prefix variable and the tqparent
* dockwidget's name will be the group the configuration is saved in
* \param group_or_prefix the prefix to append to the tqparent dockwidget's name
*/
virtual void save( KConfig *, const TQString& group_or_prefix );
/**
* Load the config using a KConfig object
*
* The combination of the group_or_prefix variable and the tqparent
* dockwidget's name will be the group the configuration is loaded from
* \param group_or_prefix the prefix to append to the tqparent dockwidget's name
*/
virtual void load( KConfig *, const TQString& group_or_prefix );
@@ -40,10 +40,10 @@ class KMDI_EXPORT KMdiDockContainer: public TQWidget, public KDockContainer
virtual ~KMdiDockContainer();
- /** Get the KDockWidget that is our tqparent */
+ /** Get the KDockWidget that is our parent */
KDockWidget *parentDockWidget();
/**
@@ -91,18 +91,18 @@ public:
* Save the config using a KConfig object
*
- * The combination of the group_or_prefix variable and the tqparent
+ * The combination of the group_or_prefix variable and the parent
* dockwidget's name will be the group the configuration is saved in
@@ -91,18 +91,18 @@ public:
* dockwidget's name will be the group the configuration is saved in
- * \param group_or_prefix the prefix to append to the tqparent dockwidget's name
+ * \param group_or_prefix the prefix to append to the parent dockwidget's name
*/
virtual void save( KConfig *, const TQString& group_or_prefix );
@@ -91,18 +91,18 @@ public:
* Load the config using a KConfig object
*
- * The combination of the group_or_prefix variable and the tqparent
+ * The combination of the group_or_prefix variable and the parent
* dockwidget's name will be the group the configuration is loaded from
@@ -91,18 +91,18 @@ public:
* dockwidget's name will be the group the configuration is loaded from
- * \param group_or_prefix the prefix to append to the tqparent dockwidget's name
+ * \param group_or_prefix the prefix to append to the parent dockwidget's name
*/
virtual void load( KConfig *, const TQString& group_or_prefix );